@@ -1,12 +1,12 @@
 import os
-import random
 import shutil
 import time
 import unittest
 from ast import literal_eval
 
-from .config import tape, TweepyTestCase, use_replay, username
-from tweepy import API, FileCache, Friendship, MemoryCache
+from tests.config import tape, TweepyTestCase, username
+from tweepy import API, FileCache, MemoryCache
+from tweepy.models import Friendship
 from tweepy.parsers import Parser
 
 test_tweet_id = '266367358078169089'
@@ -15,20 +15,6 @@ tweet_text = 'testing 1000'
 """Unit tests"""
 
 
-class TweepyErrorTests(unittest.TestCase):
-
-    def testpickle(self):
-        """Verify exceptions can be pickled and unpickled."""
-        import pickle
-        from tweepy.error import TweepError
-
-        e = TweepError('no reason', {'status': 200})
-        e2 = pickle.loads(pickle.dumps(e))
-
-        self.assertEqual(e.reason, e2.reason)
-        self.assertEqual(e.response, e2.response)
-
-
 class TweepyAPITests(TweepyTestCase):
 
     #@tape.use_cassette('testfailure.json')
@@ -61,26 +47,28 @@ class TweepyAPITests(TweepyTestCase):
     @tape.use_cassette('testusertimeline.json')
     def testusertimeline(self):
         self.api.user_timeline()
-        self.api.user_timeline('twitter')
+        self.api.user_timeline(screen_name='Twitter')
 
     @tape.use_cassette('testmentionstimeline.json')
     def testmentionstimeline(self):
         self.api.mentions_timeline()
 
-    @tape.use_cassette('testretweetsofme.json')
-    def testretweetsofme(self):
-        self.api.retweets_of_me()
+    @tape.use_cassette('testgetretweetsofme.json')
+    def testgetretweetsofme(self):
+        self.api.get_retweets_of_me()
 
-    def testretweet(self):
-        self.skipTest('Missing method to retrieve random Tweet to Retweet')
+    @tape.use_cassette('testretweetandunretweet.json')
+    def testretweetandunretweet(self):
+        self.api.retweet(test_tweet_id)
+        self.api.unretweet(test_tweet_id)
 
-    @tape.use_cassette('testretweets.json')
-    def testretweets(self):
-        self.api.retweets(test_tweet_id)
+    @tape.use_cassette('testgetretweets.json')
+    def testgetretweets(self):
+        self.api.get_retweets(test_tweet_id)
 
-    @tape.use_cassette('testretweeters.json')
-    def testretweeters(self):
-        self.api.retweeters(test_tweet_id)
+    @tape.use_cassette('testgetretweeterids.json')
+    def testgetretweeterids(self):
+        self.api.get_retweeter_ids(test_tweet_id)
 
     @tape.use_cassette('testgetstatus.json')
     def testgetstatus(self):
@@ -108,40 +96,47 @@ class TweepyAPITests(TweepyTestCase):
 
     @tape.use_cassette('testupdatestatuswithmedia.yaml', serializer='yaml')
     def testupdatestatuswithmedia(self):
-        update = self.api.update_with_media('examples/banner.png', status=tweet_text)
+        update = self.api.update_status_with_media(tweet_text, 'examples/banner.png')
         self.assertIn(tweet_text + ' https://t.co', update.text)
 
-    @tape.use_cassette('testgetuser.json')
+    @tape.use_cassette('testmediauploadpng.yaml', serializer='yaml')
+    def testmediauploadpng(self):
+        self.api.media_upload('examples/banner.png')
+
+    @tape.use_cassette('testmediauploadgif.yaml', serializer='yaml')
+    def testmediauploadgif(self):
+        self.api.media_upload('examples/animated.gif')
+
+    @tape.use_cassette('testmediauploadmp4.yaml', serializer='yaml')
+    def testmediauploadmp4(self):
+        self.api.media_upload('examples/video.mp4')
+
+    @tape.use_cassette('testgetuser.yaml', serializer='yaml')
     def testgetuser(self):
-        u = self.api.get_user('Twitter')
+        u = self.api.get_user(screen_name='Twitter')
         self.assertEqual(u.screen_name, 'Twitter')
 
-        u = self.api.get_user(783214)
+        u = self.api.get_user(user_id=783214)
         self.assertEqual(u.screen_name, 'Twitter')
 
     @tape.use_cassette('testlookupusers.json')
     def testlookupusers(self):
         def check(users):
             self.assertEqual(len(users), 2)
-        check(self.api.lookup_users(user_ids=[6844292, 6253282]))
-        check(self.api.lookup_users(screen_names=['twitterapi', 'twitter']))
+        check(self.api.lookup_users(user_id=[6844292, 6253282]))
+        check(self.api.lookup_users(screen_name=['twitterapi', 'twitter']))
 
     @tape.use_cassette('testsearchusers.json')
     def testsearchusers(self):
         self.api.search_users('twitter')
 
-    @tape.use_cassette('testme.json')
-    def testme(self):
-        me = self.api.me()
-        self.assertEqual(me.screen_name, username)
+    @tape.use_cassette('testgetdirectmessages.json')
+    def testgetdirectmessages(self):
+        self.api.get_direct_messages()
 
-    @tape.use_cassette('testlistdirectmessages.json')
-    def testlistdirectmessages(self):
-        self.api.list_direct_messages()
-
-    @tape.use_cassette('testsendanddestroydirectmessage.json')
-    def testsendanddestroydirectmessage(self):
-        me = self.api.me()
+    @tape.use_cassette('testsendanddeletedirectmessage.json')
+    def testsendanddeletedirectmessage(self):
+        me = self.api.verify_credentials()
 
         # send
         sent_dm = self.api.send_direct_message(me.id, text='test message')
@@ -150,41 +145,41 @@ class TweepyAPITests(TweepyTestCase):
         self.assertEqual(int(sent_dm.message_create['target']['recipient_id']), me.id)
 
         # destroy
-        self.api.destroy_direct_message(sent_dm.id)
+        self.api.delete_direct_message(sent_dm.id)
 
-    @tape.use_cassette('testcreatedestroyfriendship.json')
+    @tape.use_cassette('testcreatedestroyfriendship.yaml', serializer='yaml')
     def testcreatedestroyfriendship(self):
-        enemy = self.api.destroy_friendship('Twitter')
+        enemy = self.api.destroy_friendship(screen_name='Twitter')
         self.assertEqual(enemy.screen_name, 'Twitter')
 
-        friend = self.api.create_friendship('Twitter')
+        friend = self.api.create_friendship(screen_name='Twitter')
         self.assertEqual(friend.screen_name, 'Twitter')
 
-    @tape.use_cassette('testshowfriendship.json')
-    def testshowfriendship(self):
-        source, target = self.api.show_friendship(target_screen_name='twitter')
+    @tape.use_cassette('testgetfriendship.json')
+    def testgetfriendship(self):
+        source, target = self.api.get_friendship(target_screen_name='twitter')
         self.assertTrue(isinstance(source, Friendship))
         self.assertTrue(isinstance(target, Friendship))
 
-    @tape.use_cassette('testfriendsids.json')
-    def testfriendsids(self):
-        self.api.friends_ids(username)
+    @tape.use_cassette('testgetfriendids.yaml', serializer='yaml')
+    def testgetfriendids(self):
+        self.api.get_friend_ids(screen_name=username)
 
-    @tape.use_cassette('testfollowersids.json')
-    def testfollowersids(self):
-        self.api.followers_ids(username)
+    @tape.use_cassette('testgetfollowerids.yaml', serializer='yaml')
+    def testgetfollowerids(self):
+        self.api.get_follower_ids(screen_name=username)
 
-    @tape.use_cassette('testfriends.json')
-    def testfriends(self):
-        self.api.friends(username)
+    @tape.use_cassette('testgetfriends.yaml', serializer='yaml')
+    def testgetfriends(self):
+        self.api.get_friends(screen_name=username)
 
-    @tape.use_cassette('testfollowers.json')
-    def testfollowers(self):
-        self.api.followers(username)
+    @tape.use_cassette('testgetfollowers.yaml', serializer='yaml')
+    def testgetfollowers(self):
+        self.api.get_followers(screen_name=username)
 
     @tape.use_cassette('testverifycredentials.json')
     def testverifycredentials(self):
-        self.assertNotEqual(self.api.verify_credentials(), False)
+        self.api.verify_credentials()
 
         # make sure that `me.status.entities` is not an empty dict
         me = self.api.verify_credentials(include_entities=True)
@@ -200,7 +195,7 @@ class TweepyAPITests(TweepyTestCase):
 
     @tape.use_cassette('testupdateprofilecolors.json')
     def testupdateprofilecolors(self):
-        original = self.api.me()
+        original = self.api.verify_credentials()
         updated = self.api.update_profile(profile_link_color='D0F900')
 
         # restore colors
@@ -225,7 +220,7 @@ class TweepyAPITests(TweepyTestCase):
 
     @tape.use_cassette('testupdateprofile.json')
     def testupdateprofile(self):
-        original = self.api.me()
+        original = self.api.verify_credentials()
         profile = {
             'name': 'Tweepy test 123',
             'location': 'pytopia',
@@ -241,55 +236,55 @@ class TweepyAPITests(TweepyTestCase):
             if k == 'email': continue
             self.assertEqual(getattr(updated, k), v)
 
-    @tape.use_cassette('testfavorites.json')
-    def testfavorites(self):
-        self.api.favorites()
+    @tape.use_cassette('testgetfavorites.json')
+    def testgetfavorites(self):
+        self.api.get_favorites()
 
     @tape.use_cassette('testcreatedestroyfavorite.json')
     def testcreatedestroyfavorite(self):
         self.api.create_favorite(145344012)
         self.api.destroy_favorite(145344012)
 
-    @tape.use_cassette('testcreatedestroyblock.json')
+    @tape.use_cassette('testcreatedestroyblock.yaml', serializer='yaml')
     def testcreatedestroyblock(self):
-        self.api.create_block('twitter')
-        self.api.destroy_block('twitter')
-        self.api.create_friendship('twitter')  # restore
+        self.api.create_block(screen_name='twitter')
+        self.api.destroy_block(screen_name='twitter')
+        self.api.create_friendship(screen_name='twitter')  # restore
 
-    @tape.use_cassette('testblocks.json')
-    def testblocks(self):
-        self.api.blocks()
+    @tape.use_cassette('testgetblocks.json')
+    def testgetblocks(self):
+        self.api.get_blocks()
 
-    @tape.use_cassette('testblocksids.json')
-    def testblocksids(self):
-        self.api.blocks_ids()
+    @tape.use_cassette('testgetblockedids.json')
+    def testgetblockedids(self):
+        self.api.get_blocked_ids()
 
-    # TODO: Rewrite test to be less brittle. It fails way too often.
-    # def testcreateupdatedestroylist(self):
-    #     params = {
-    #         'owner_screen_name': username,
-    #         'slug': 'tweeps'
-    #     }
-    #     l = self.api.create_list(name=params['slug'], **params)
-    #     l = self.api.update_list(list_id=l.id, description='updated!')
-    #     self.assertEqual(l.description, 'updated!')
-    #     self.api.destroy_list(list_id=l.id)
+    @tape.use_cassette('testcreateupdatedestroylist.yaml', serializer='yaml')
+    def testcreateupdatedestroylist(self):
+        l = self.api.create_list(name="tweeps")
+        l = self.api.update_list(list_id=l.id, description='updated!')
+        self.assertEqual(l.description, 'updated!')
+        self.api.destroy_list(list_id=l.id)
 
-    @tape.use_cassette('testlistsall.json')
-    def testlistsall(self):
-        self.api.lists_all()
+    @tape.use_cassette('testgetlists.json')
+    def testgetlists(self):
+        self.api.get_lists()
 
-    @tape.use_cassette('testlistsmemberships.json')
-    def testlistsmemberships(self):
-        self.api.lists_memberships()
+    @tape.use_cassette('testgetlistmemberships.json')
+    def testgetlistmemberships(self):
+        self.api.get_list_memberships()
 
-    @tape.use_cassette('testlistssubscriptions.json')
-    def testlistssubscriptions(self):
-        self.api.lists_subscriptions()
+    @tape.use_cassette('testgetlistownerships.json')
+    def testgetlistownerships(self):
+        self.api.get_list_ownerships()
+
+    @tape.use_cassette('testgetlistsubscriptions.json')
+    def testgetlistsubscriptions(self):
+        self.api.get_list_subscriptions()
 
     @tape.use_cassette('testlisttimeline.json')
     def testlisttimeline(self):
-        self.api.list_timeline('Twitter', 'Official-Twitter-Accounts')
+        self.api.list_timeline(owner_screen_name='Twitter', slug='Official-Twitter-Accounts')
 
     @tape.use_cassette('testgetlist.json')
     def testgetlist(self):
@@ -323,13 +318,13 @@ class TweepyAPITests(TweepyTestCase):
         assert_list(self.api.add_list_members(**params))
         assert_list(self.api.remove_list_members(**params))
 
-    @tape.use_cassette('testlistmembers.json')
-    def testlistmembers(self):
-        self.api.list_members('Twitter', 'Official-Twitter-Accounts')
+    @tape.use_cassette('testgetlistmembers.json')
+    def testgetlistmembers(self):
+        self.api.get_list_members(owner_screen_name='Twitter', slug='Official-Twitter-Accounts')
 
-    @tape.use_cassette('testshowlistmember.json')
-    def testshowlistmember(self):
-        self.assertTrue(self.api.show_list_member(owner_screen_name='Twitter', slug='Official-Twitter-Accounts', screen_name='TwitterAPI'))
+    @tape.use_cassette('testgetlistmember.json')
+    def testgetlistmember(self):
+        self.assertTrue(self.api.get_list_member(owner_screen_name='Twitter', slug='Official-Twitter-Accounts', screen_name='TwitterAPI'))
 
     @tape.use_cassette('testsubscribeunsubscribelist.json')
     def testsubscribeunsubscribelist(self):
@@ -340,24 +335,24 @@ class TweepyAPITests(TweepyTestCase):
         self.api.subscribe_list(**params)
         self.api.unsubscribe_list(**params)
 
-    @tape.use_cassette('testlistsubscribers.json')
-    def testlistsubscribers(self):
-        self.api.list_subscribers('Twitter', 'Official-Twitter-Accounts')
+    @tape.use_cassette('testgetlistsubscribers.json')
+    def testgetlistsubscribers(self):
+        self.api.get_list_subscribers(owner_screen_name='Twitter', slug='Official-Twitter-Accounts')
 
-    @tape.use_cassette('testshowlistsubscriber.json')
-    def testshowlistsubscriber(self):
-        self.assertTrue(self.api.show_list_subscriber('Twitter', 'Official-Twitter-Accounts', 'TwitterMktg'))
+    @tape.use_cassette('testgetlistsubscriber.json')
+    def testgetlistsubscriber(self):
+        self.assertTrue(self.api.get_list_subscriber(owner_screen_name='Twitter', slug='Official-Twitter-Accounts', screen_name='TwitterMktg'))
 
     @tape.use_cassette('testsavedsearches.json')
     def testsavedsearches(self):
         s = self.api.create_saved_search('test')
-        self.api.saved_searches()
+        self.api.get_saved_searches()
         self.assertEqual(self.api.get_saved_search(s.id).query, 'test')
         self.api.destroy_saved_search(s.id)
 
-    @tape.use_cassette('testsearch.json')
-    def testsearch(self):
-        self.api.search('tweepy')
+    @tape.use_cassette('testsearchtweets.json')
+    def testsearchtweets(self):
+        self.api.search_tweets('tweepy')
 
     @tape.use_cassette('testgeoapis.json')
     def testgeoapis(self):
@@ -365,13 +360,8 @@ class TweepyAPITests(TweepyTestCase):
             """Return True if a given place_name is in place_list."""
             return any(x.full_name.lower() == place_name.lower() for x in place_list)
 
-        twitter_hq = self.api.geo_similar_places(lat='37.7821120598956',
-                                                 long='-122.400612831116',
-                                                 name='South of Market Child Care')
-        # Assumes that twitter_hq is first Place returned...
-        self.assertEqual(twitter_hq[0].id, '1d019624e6b4dcff')
         # Test various API functions using Austin, TX, USA
-        self.assertEqual(self.api.geo_id(id='1ffd3558f2e98349').full_name, 'Dogpatch, San Francisco')
+        self.assertEqual(self.api.geo_id(place_id='1ffd3558f2e98349').full_name, 'Dogpatch, San Francisco')
         self.assertTrue(place_name_in_list('Austin, TX',
             self.api.reverse_geocode(lat=30.2673701685, long= -97.7426147461)))  # Austin, TX, USA
 
@@ -387,7 +377,7 @@ class TweepyAPITests(TweepyTestCase):
         }
         self.assertTrue(expected_dict in languages)
 
-    @tape.use_cassette('testcachedresult.json')
+    @tape.use_cassette('testcachedresult.yaml', serializer='yaml')
     def testcachedresult(self):
         self.api.cache = MemoryCache()
         self.api.home_timeline()
@@ -395,20 +385,19 @@ class TweepyAPITests(TweepyTestCase):
         self.api.home_timeline()
         self.assertTrue(self.api.cached_result)
 
-    @tape.use_cassette('testcachedresult.json')
+    @tape.use_cassette('testcachedresult.yaml', serializer='yaml')
     def testcachedifferentqueryparameters(self):
         self.api.cache = MemoryCache()
 
-        user1 = self.api.get_user('TweepyDev')
+        user1 = self.api.get_user(screen_name='TweepyDev')
         self.assertFalse(self.api.cached_result)
         self.assertEqual('TweepyDev', user1.screen_name)
 
-        user2 = self.api.get_user('Twitter')
+        user2 = self.api.get_user(screen_name='Twitter')
         self.assertEqual('Twitter', user2.screen_name)
         self.assertFalse(self.api.cached_result)
 
 
-
 class TweepyCacheTests(unittest.TestCase):
     timeout = 0.5
     memcache_servers = ['127.0.0.1:11211']  # must be running for test to pass
@@ -432,8 +421,8 @@ class TweepyCacheTests(unittest.TestCase):
             self.assertEqual(self.cache.count(), 0, 'Cache cleanup failed')
 
         # test count
-        for i in range(0, 20):
-            self.cache.store('testkey%i' % i, 'testvalue')
+        for i in range(20):
+            self.cache.store(f'testkey{i}', 'testvalue')
         self.assertEqual(self.cache.count(), 20, 'Count is wrong')
 
         # test flush
@@ -454,5 +443,6 @@ class TweepyCacheTests(unittest.TestCase):
             if os.path.exists('cache_test_dir'):
                 shutil.rmtree('cache_test_dir')
 
+
 if __name__ == '__main__':
     unittest.main()
