@@ -7,6 +7,7 @@ import datetime
 import logging
 from platform import python_version
 import time
+import warnings
 
 import requests
 
@@ -37,6 +38,8 @@ class Client:
 
     Twitter API v2 Client
 
+    .. versionadded:: 4.0
+
     Parameters
     ----------
     bearer_token : Optional[str]
@@ -264,7 +267,9 @@ class Client:
         id = self.access_token.partition('-')[0]
         route = f"/2/users/{id}/likes/{tweet_id}"
 
-        return self._make_request("DELETE", route, user_auth=True)
+        return self._make_request(
+            "DELETE", route, user_auth=True
+        )
 
     def get_liking_users(self, id, *, user_auth=False, **params):
         """get_liking_users(id, *, expansions, media_fields, place_fields, \
@@ -410,7 +415,9 @@ class Client:
         id = self.access_token.partition('-')[0]
         route = f"/2/users/{id}/retweets/{source_tweet_id}"
 
-        return self._make_request("DELETE", route, user_auth=True)
+        return self._make_request(
+            "DELETE", route, user_auth=True
+        )
 
     def get_retweeters(self, id, *, user_auth=False, **params):
         """get_retweeters(id, *, expansions, media_fields, place_fields, \
@@ -1188,12 +1195,15 @@ class Client:
 
     # Follows
 
-    def unfollow(self, target_user_id):
+    def unfollow_user(self, target_user_id):
         """Allows a user ID to unfollow another user.
 
         The request succeeds with no action when the authenticated user sends a
         request to a user they're not following or have already unfollowed.
 
+        .. versionchanged:: 4.2
+            Renamed from :meth:`Client.unfollow`
+
         Parameters
         ----------
         target_user_id : Union[int, str]
@@ -1210,7 +1220,21 @@ class Client:
         source_user_id = self.access_token.partition('-')[0]
         route = f"/2/users/{source_user_id}/following/{target_user_id}"
 
-        return self._make_request("DELETE", route, user_auth=True)
+        return self._make_request(
+            "DELETE", route, user_auth=True
+        )
+
+    def unfollow(self, target_user_id):
+        """Alias for :meth:`Client.unfollow_user`
+
+        .. deprecated:: 4.2
+            Use :meth:`Client.unfollow_user` instead.
+        """
+        warnings.warn(
+            "Client.unfollow is deprecated; use Client.unfollow_user instead.",
+            DeprecationWarning
+        )
+        self.unfollow_user(target_user_id)
 
     def get_users_followers(self, id, *, user_auth=False, **params):
         """get_users_followers( \
@@ -1307,7 +1331,7 @@ class Client:
             ), data_type=User, user_auth=user_auth
         )
 
-    def follow(self, target_user_id):
+    def follow_user(self, target_user_id):
         """Allows a user ID to follow another user.
 
         If the target user does not have public Tweets, this endpoint will send
@@ -1317,6 +1341,9 @@ class Client:
         request to a user they're already following, or if they're sending a
         follower request to a user that does not have public Tweets.
 
+        .. versionchanged:: 4.2
+            Renamed from :meth:`Client.follow`
+
         Parameters
         ----------
         target_user_id : Union[int, str]
@@ -1338,6 +1365,18 @@ class Client:
             user_auth=True
         )
 
+    def follow(self, target_user_id):
+        """Alias for :meth:`Client.follow_user`
+
+        .. deprecated:: 4.2
+            Use :meth:`Client.follow_user` instead.
+        """
+        warnings.warn(
+            "Client.follow is deprecated; use Client.follow_user instead.",
+            DeprecationWarning
+        )
+        self.follow_user(target_user_id)
+
     # Mutes
 
     def unmute(self, target_user_id):
@@ -1362,7 +1401,9 @@ class Client:
         source_user_id = self.access_token.partition('-')[0]
         route = f"/2/users/{source_user_id}/muting/{target_user_id}"
 
-        return self._make_request("DELETE", route, user_auth=True)
+        return self._make_request(
+            "DELETE", route, user_auth=True
+        )
 
     def get_muted(self, **params):
         """get_muted(*, expansions, max_results, pagination_token, \
@@ -1370,6 +1411,8 @@ class Client:
 
         Returns a list of users who are muted by the authenticating user.
 
+        .. versionadded:: 4.1
+
         Parameters
         ----------
         expansions : Union[List[str], str]
@@ -1549,20 +1592,22 @@ class Client:
 
     # Search Spaces
 
-    def search_spaces(self, query, state, **params):
-        """search_spaces(query, state, *, expansions, max_results, \
-                         space_fields, user_fields)
+    def search_spaces(self, query, **params):
+        """search_spaces(query, *, expansions, max_results, space_fields, \
+                         state, user_fields)
 
         Return live or scheduled Spaces matching your specified search terms
 
+        .. versionadded:: 4.1
+
+        .. versionchanged:: 4.2
+            ``state`` is now an optional parameter.
+
         Parameters
         ----------
         query : str
             Your search term. This can be any text (including mentions and
             Hashtags) present in the title of the Space.
-        state : str
-            Determines the type of results to return. Use ``live`` to return
-            live Spaces or ``scheduled`` to return upcoming Spaces.
         expansions : Union[List[str], str]
             :ref:`expansions_parameter`
         max_results : int
@@ -1570,6 +1615,10 @@ class Client:
             value between 1 and 100.
         space_fields : Union[List[str], str]
             :ref:`space_fields_parameter`
+        state : str
+            Determines the type of results to return. This endpoint returns all
+            Spaces by default. Use ``live`` to only return live Spaces or
+            ``scheduled`` to only return upcoming Spaces.
         user_fields : Union[List[str], str]
             :ref:`user_fields_parameter`
 
@@ -1582,11 +1631,10 @@ class Client:
         https://developer.twitter.com/en/docs/twitter-api/spaces/search/api-reference/get-spaces-search
         """
         params["query"] = query
-        params["state"] = state
         return self._make_request(
             "GET", "/2/spaces/search", params=params,
             endpoint_parameters=(
-                "query", "state", "expansions", "max_results", "space.fields",
+                "query", "expansions", "max_results", "space.fields", "state",
                 "user.fields"
             ), data_type=Space
         )
@@ -1600,6 +1648,8 @@ class Client:
         specified user IDs if specified). Up to 100 comma-separated Space or
         user IDs can be looked up using this endpoint.
 
+        .. versionadded:: 4.1
+
         Parameters
         ----------
         ids : Union[List[str], str]
@@ -1653,6 +1703,8 @@ class Client:
         Returns a variety of information about a single Space specified by the
         requested ID.
 
+        .. versionadded:: 4.1
+
         Parameters
         ----------
         id : Union[List[str], str]
@@ -1679,6 +1731,256 @@ class Client:
             ), data_type=Space
         )
 
+    # Manage Lists
+
+    def delete_list(self, id):
+        """Enables the authenticated user to delete a List that they own.
+
+        .. versionadded:: 4.2
+
+        Parameters
+        ----------
+        id : Union[int, str]
+            The ID of the List to be deleted.
+
+        Returns
+        -------
+        Union[dict, requests.Response, Response]
+
+        References
+        ----------
+        https://developer.twitter.com/en/docs/twitter-api/lists/manage-lists/api-reference/delete-lists-id
+        """
+
+        return self._make_request(
+            "DELETE", f"/2/lists/{id}", user_auth=True
+        )
+
+    def remove_list_member(self, id, user_id):
+        """Enables the authenticated user to remove a member from a List they
+        own.
+
+        .. versionadded:: 4.2
+
+        Parameters
+        ----------
+        id : Union[int, str]
+            The ID of the List you are removing a member from.
+        user_id : Union[int, str]
+            The ID of the user you wish to remove as a member of the List.
+
+        Returns
+        -------
+        Union[dict, requests.Response, Response]
+
+        References
+        ----------
+        https://developer.twitter.com/en/docs/twitter-api/lists/manage-lists/api-reference/delete-lists-id-members-user_id
+        """
+
+        return self._make_request(
+            "DELETE", f"/2/lists/{id}/members/{user_id}", user_auth=True
+        )
+
+    def unfollow_list(self, list_id):
+        """Enables the authenticated user to unfollow a List.
+
+        .. versionadded:: 4.2
+
+        Parameters
+        ----------
+        list_id : Union[int, str]
+            The ID of the List that you would like the user to unfollow.
+
+        Returns
+        -------
+        Union[dict, requests.Response, Response]
+
+        References
+        ----------
+        https://developer.twitter.com/en/docs/twitter-api/lists/manage-lists/api-reference/delete-users-id-followed-lists-list_id
+        """
+        id = self.access_token.partition('-')[0]
+        route = f"/2/users/{id}/followed_lists/{list_id}"
+
+        return self._make_request(
+            "DELETE", route, user_auth=True
+        )
+
+    def unpin_list(self, list_id):
+        """Enables the authenticated user to unpin a List.
+
+        .. versionadded:: 4.2
+
+        Parameters
+        ----------
+        list_id : Union[int, str]
+            The ID of the List that you would like the user to unpin.
+
+        Returns
+        -------
+        Union[dict, requests.Response, Response]
+
+        References
+        ----------
+        https://developer.twitter.com/en/docs/twitter-api/lists/manage-lists/api-reference/delete-users-id-pinned-lists-list_id
+        """
+        id = self.access_token.partition('-')[0]
+        route = f"/2/users/{id}/pinned_lists/{list_id}"
+
+        return self._make_request(
+            "DELETE", route, user_auth=True
+        )
+
+    def update_list(self, id, *, description=None, name=None, private=None):
+        """Enables the authenticated user to update the meta data of a
+        specified List that they own.
+
+        .. versionadded:: 4.2
+
+        Parameters
+        ----------
+        id : Union[int, str]
+            The ID of the List to be updated.
+        description : str
+            Updates the description of the List.
+        name : str
+            Updates the name of the List.
+        private : bool
+            Determines whether the List should be private.
+
+        Returns
+        -------
+        Union[dict, requests.Response, Response]
+
+        References
+        ----------
+        https://developer.twitter.com/en/docs/twitter-api/lists/manage-lists/api-reference/put-lists-id
+        """
+        json = {}
+
+        if description is not None:
+            json["description"] = description
+
+        if name is not None:
+            json["name"] = name
+
+        if private is not None:
+            json["private"] = private
+
+        return self._make_request(
+            "PUT", f"/2/lists/{id}", json=json, user_auth=True
+        )
+
+    def create_list(self, name, *, description=None, private=None):
+        """Enables the authenticated user to create a List.
+
+        .. versionadded:: 4.2
+
+        Parameters
+        ----------
+        name : str
+            The name of the List you wish to create.
+        description : str
+            Description of the List.
+        private : bool
+            Determine whether the List should be private.
+
+        Returns
+        -------
+        Union[dict, requests.Response, Response]
+
+        References
+        ----------
+        https://developer.twitter.com/en/docs/twitter-api/lists/manage-lists/api-reference/post-lists
+        """
+        json = {"name": name}
+
+        if description is not None:
+            json["description"] = description
+
+        if private is not None:
+            json["private"] = private
+
+        return self._make_request(
+            "POST", f"/2/lists", json=json, user_auth=True
+        )
+
+    def add_list_member(self, id, user_id):
+        """Enables the authenticated user to add a member to a List they own.
+
+        .. versionadded:: 4.2
+
+        Parameters
+        ----------
+        id : Union[int, str]
+            The ID of the List you are adding a member to.
+        user_id : Union[int, str]
+            The ID of the user you wish to add as a member of the List.
+
+        Returns
+        -------
+        Union[dict, requests.Response, Response]
+
+        References
+        ----------
+        https://developer.twitter.com/en/docs/twitter-api/lists/manage-lists/api-reference/post-lists-id-members
+        """
+        return self._make_request(
+            "POST", f"/2/lists/{id}/members", json={"user_id": str(user_id)},
+            user_auth=True
+        )
+
+    def follow_list(self, list_id):
+        """Enables the authenticated user to follow a List.
+
+        .. versionadded:: 4.2
+
+        Parameters
+        ----------
+        list_id : Union[int, str]
+            The ID of the List that you would like the user to follow.
+
+        Returns
+        -------
+        Union[dict, requests.Response, Response]
+
+        References
+        ----------
+        https://developer.twitter.com/en/docs/twitter-api/lists/manage-lists/api-reference/post-users-id-followed-lists
+        """
+        id = self.access_token.partition('-')[0]
+        route = f"/2/users/{id}/followed_lists"
+
+        return self._make_request(
+            "POST", route, json={"list_id": str(list_id)}, user_auth=True
+        )
+
+    def pin_list(self, list_id):
+        """Enables the authenticated user to pin a List.
+
+        .. versionadded:: 4.2
+
+        Parameters
+        ----------
+        list_id : Union[int, str]
+            The ID of the List that you would like the user to pin.
+
+        Returns
+        -------
+        Union[dict, requests.Response, Response]
+
+        References
+        ----------
+        https://developer.twitter.com/en/docs/twitter-api/lists/manage-lists/api-reference/post-users-id-pinned-lists
+        """
+        id = self.access_token.partition('-')[0]
+        route = f"/2/users/{id}/pinned_lists"
+
+        return self._make_request(
+            "POST", route, json={"list_id": str(list_id)}, user_auth=True
+        )
+
     # Batch Compliance
 
     def get_compliance_jobs(self, type, **params):
@@ -1686,6 +1988,8 @@ class Client:
 
         Returns a list of recent compliance jobs.
 
+        .. versionadded:: 4.1
+
         Parameters
         ----------
         type : str
@@ -1713,6 +2017,8 @@ class Client:
     def get_compliance_job(self, id):
         """Get a single compliance job with the specified ID.
 
+        .. versionadded:: 4.1
+
         Parameters
         ----------
         id : Union[int, str]
@@ -1726,7 +2032,9 @@ class Client:
         ----------
         https://developer.twitter.com/en/docs/twitter-api/compliance/batch-compliance/api-reference/get-compliance-jobs-id
         """
-        return self._make_request("GET", f"/2/compliance/jobs/{id}")
+        return self._make_request(
+            "GET", f"/2/compliance/jobs/{id}"
+        )
 
     def create_compliance_job(self, type, *, name=None, resumable=None):
         """Creates a new compliance job for Tweet IDs or user IDs.
@@ -1737,6 +2045,8 @@ class Client:
 
         You can run one batch job at a time.
 
+        .. versionadded:: 4.1
+
         Parameters
         ----------
         type : str
